import { insertRound } from '@/lib/server/db/queries/rounds';
import type { RequestHandler } from './$types';
import type { RoundInsert } from '@/lib/server/db/schema/rounds';
import { SchedulingMode } from '@/types';

export const POST: RequestHandler = async ({ request, params }) => {
	// get body from request
	// get competition id from url
	const body = await request.json();
	let competitionId;
	try {
		competitionId = params.id;
	} catch {
		throw new Error('Invalid competition id');
	}
	if (competitionId === '') {
		throw new Error('Invalid competition id');
	}

	let schedulingMode: SchedulingMode;
	let name: string;
	let nbMmatches: number;

	try {
		schedulingMode = SchedulingMode[body.scheduling_mode as keyof typeof SchedulingMode];
		name = body.name;
		nbMmatches = body.nb_matches;
	} catch {
		throw new Error('Invalid scheduling mode');
	}

	// create round
	const roundInsert: RoundInsert = {
		nb_matches: nbMmatches,
		name: name,
		competition_id: competitionId,
		scheduling_mode: schedulingMode,
		round_number: -1
	};

	const [round] = await insertRound(competitionId, roundInsert);

	return new Response(JSON.stringify(round), {
		headers: {
			'Content-Type': 'application/json'
		}
	});
};
