import { getCompetition } from '@/lib/server/db/queries/competitions';
import { getRound } from '@/lib/server/db/queries/rounds';
import type { PageServerLoad } from './$types';

export const load: PageServerLoad = async ({ params, locals }) => {
	const competitionId = params.id;
	const roundId = params.round_id;
	const { user } = locals;
	if (!user) {
		throw new Error('Unauthorized');
	}
	if (competitionId === '') {
		throw new Error('Invalid competition id');
	}
	if (roundId === '') {
		throw new Error('Invalid round id');
	}

	const competition = await getCompetition(competitionId);
	if (!competition) {
		throw new Error('Invalid competition');
	}
	if (competition.owner !== locals.user.id) {
		throw new Error('Unauthorized');
	}
	const round = await getRound(competitionId, roundId);
	if (!round) {
		throw new Error('Invalid round');
	}
	return { competition: competition, round };
};
